module.exports = function(grunt) {
    require('jit-grunt')(grunt);

    grunt.initConfig({
        pkg: grunt.file.readJSON( 'package.json' ),
        // Clean the build folder
        clean: {
            build: {
                src: ['__build/']
            },
            build2: {
                src: ['__build/*','!__build/<%= pkg.name %>.zip']
            },
            rtl: {
                src: ['assets/css-rtl/*']
            }
        },
        // make pot to build folder
        makepot: {
            build: {
                options: {
                    cwd: '__build',
                    domainPath: 'languages',
                    type: 'wp-theme',
                    processPot: function( pot, options ) {
                        pot.headers['report-msgid-bugs-to'] = 'support@axilWeb.com';
                        pot.headers['last-translator'] = 'AxilWeb <info@axilWeb.com>';
                        pot.headers['language-team'] = 'AxilWeb <info@axilWeb.com>';
                        return pot;
                    }
                }
            }
        },
        // Copy to build folder
        copy: {
            build: {
                src: ['**', '!node_modules/**', '!__junk/**', '!package-lock.json','!Gruntfile.js', '!todo.txt', '!sftp-config.json', '!testing.html'],
                dest: '__build/',
            }
        },        
        // Compress the build folder into an upload-ready zip file
        compress: {
            build: {
                options: {
                    archive: '__build/<%= pkg.name %>.zip'
                },
                expand: true,
                cwd: '__build/',
                src: ['**/*'],
                dest: '<%= pkg.name %>/'
            }
        },
        // RTL
        rtlcss: {
            final: {
                options: {
                  opts: {
                    "autoRename": false,
                    "autoRenameStrict": false,
                    "blacklist":{},
                    "clean": true,
                    "greedy": false,
                    "processUrls": false,
                    "stringMap":[]
                  },
                  saveUnmodified: true,
                },
                // files: {
                //     'assets/css/rtl/style.css': 'assets/css/style.css',
                //     'assets/css/rtl/vc.css': 'assets/css/vc.css'
                // },
                expand : true,
                cwd    : 'assets/css/',
                dest   : 'assets/css-rtl/',
                src    : [
                        '**/*.css',
                        '!**/owl.carousel.css',
                        '!**/owl.carousel.min.css',
                        '!**/owl.theme.default.css',
                        '!**/owl.theme.default.min.css',
                        '!**/font-awesome.min.css'
                ]
            }
        }
    });
    
    grunt.loadNpmTasks( 'grunt-wp-i18n' );

    // Build task
    grunt.registerTask( 'build', ['clean:build', 'copy:build', 'makepot:build', 'compress:build', 'clean:build2' ]);    
};